@@ -18,7 +18,7 @@ SelModel<-function(InVVTestindex,keindex)
                 }
   else {
   if (pick == 3){
-      cat("\nBye~~ \n\n")
+      cat("\nThanks for using ivivc for R.  Bye now. \n\n")
                 }  
    }
   }
