@@ -4,12 +4,12 @@ cat("\n")
   file.menu <- c("Back to ivivc menu",
                  "Quit")
   cat("\n")
-  pick <- menu(file.menu, title = " << Try again or bye~ >> ")
+  pick <- menu(file.menu, title = " << Try again or quit ivivc?>> ")
     if (pick == 1){
      cat("\n")
      run()}
     else {
      if (pick == 2){
-        cat("\nBye~~ \n\n")}
+        cat("\nThanks for using ivivc for R. Bye now. \n\n")}
         }
   }
\ No newline at end of file
