@@ -145,14 +145,14 @@ ffirst.lag<- function(InVVRefindex,
 #The value of parameter obtained from genetic algorithm 
       if (MMe) {
           gen<-genoud(objfun,nvars=4,max=FALSE,pop.size=30,max.generations=20,
-               wait.generations=10,starting.value=c(par[1,2],par[2,2],par[3,2],par[4,2]),
+               wait.generations=10,starting.values=c(par[1,2],par[2,2],par[3,2],par[4,2]),
                BFGS=FALSE,print.level=0,boundary.enforcement=2,
                Domains=matrix(c(0.01,1,1,1,10,100,100,100),4,2),
                MemoryMatrix=TRUE) 
       } 
       else {
           gen<-genoud(objfun,nvars=3,max=FALSE,pop.size=20,max.generations=15,
-               wait.generations=10,starting.value=c(par[1,2],par[2,2],par[3,2]),
+               wait.generations=10,starting.values=c(par[1,2],par[2,2],par[3,2]),
                BFGS=FALSE,print.level=0,boundary.enforcement=2,
                Domains=matrix(c(0.01,0.01,1,10,1,100),3,2),
                MemoryMatrix=TRUE)
