@@ -106,7 +106,7 @@ fzero.nolag <- function(InVVRefindex,
         if (MMe) {
          gen<-genoud(objfun,nvars=4,max=FALSE,pop.size=30,max.generations=20,
               wait.generations=10,
-              starting.value=c(par[1,2],par[2,2],par[3,2],par[4,2]),
+              starting.values=c(par[1,2],par[2,2],par[3,2],par[4,2]),
               BFGS=FALSE,print.level=0,boundary.enforcement=2,
               Domains=matrix(c(1,1,1,1,50,100,100,100),4,2),
               MemoryMatrix=TRUE)
@@ -114,7 +114,7 @@ fzero.nolag <- function(InVVRefindex,
       else {
          gen<-genoud(objfun,nvars=3,max=FALSE,pop.size=30,max.generations=20,
               wait.generations=10,
-              starting.value=c(par[1,2],par[2,2],par[3,2]),
+              starting.values=c(par[1,2],par[2,2],par[3,2]),
               BFGS=FALSE,print.level=0,boundary.enforcement=2,
               Domains=matrix(c(1,0.01,1,50,1,100),3,2),
               MemoryMatrix=TRUE)
